
Global cur_question = nothing;

Class Question
  with
	query "^   ? []",
	answer_wait [; "   ,  . []"; ],
	answer_yes [; "  @<<@>>,  . []"; ],
	answer_no [; "  @<<@>>,  . []"; ],
	variant 0,	! useful value, usually from last question
	number 0, 	! turn counter
	daemon 0,	! called every turn after counter updates
	time_limit -1;	! if non-negative, the amount of time before a wait-answer

[ SetQuestion qx var;
	cur_question = qx;
	if (cur_question) {
		cur_question.number = 0;
		cur_question.variant = var;
	}
];

[ QuestionAnswerWait   qx;
	qx = cur_question;
	if (qx == nothing) {
		"    ,    .   -. []";
	}
	cur_question = nothing;
	num_wait_answers++;
	qx.answer_wait();
];

[ QuestionAnswerYes   qx;
	qx = cur_question;
	if (qx == nothing) {
		" , @<<   @>>. []";
	}
	cur_question = nothing;
	num_yes_answers++;
	qx.answer_yes();
];

[ QuestionAnswerNo   qx;
	qx = cur_question;
	if (qx == nothing) {
		" , @<<    @>>. []";
	}
	cur_question = nothing;
	num_no_answers++;
	qx.answer_no();
];

Object InterrogRoom "  "
  with
	description [;
		if (self.just_in) {
			! just came from EndScene.
			self.just_in = 0;
			if (self.first_time) {
				self.first_time = 0;
				print " ,   ,          . Ҹ      .       ,   .^^";
				print "    ,     .    .^";
			}
			else {
				print " ,  .          .^";
			}
		}
		else {
			! plain Look
			print "    ,   ,  ,    .    ,   .         .^";
		}
	],
	just_in 0, 	! set true if we've just come from EndScene.
	first_time 1;	! set true if this is the first time ever.

Object -> interrogdesk "/"
  with
	name '' '' '' '' '' '',
	description [;
		print "       .  ,  ,     ,      .^";
		if (child(self)) {
			print "^    ";
			WriteListFrom(child(self), ENGLISH_BIT);
			print ".^";
		}
		rtrue;
	],
  has scenery transparent male;

Object -> interrogwalls "/"
  with
	name '' '' '' '',
	description ",      --     .",
  has scenery pluralname;

Object -> interrogdoor "/"
  with
	name '' '',
	door_dir s_to,
	door_to InterrogRoom,
	description [;
		print "  ,  ,  .^";
		self.number2();
		rtrue;
	],
	number 0,	! counter for the man noticing you.
	number2 [;
		switch (self.number) {
			1:
				print "^       .^";
			3:
				print "^       .^";
			5:
				self.number = 4;
		}
		self.number++;
	],
	before [;
		Search:
			print "       .     ,      .^";
			self.number2();
			rtrue;
	],
  has scenery door male;

Object -> boundchair "/"
  with
	name '' '' '' '',
	description "    , , ,    .        .     ,       ,   .  , ,  ,     .     .",
	vehicle_name " (  )",
	react_before [;
		Exit:
			"    .";
		Go:
			"   .";
		Jump, JumpOver:
			", , .";
		Hide:
			return L__M(##Hide, 3);
		WaveHands:
			" .    -.";
		Open, Close, Push, Pull, Turn, Attack, AttackWith, Cut, Touch, 
			Rub, Take, Taste, SwitchOn, SwitchOff:
			if (noun ~= self or interrogleads or interrogbands)
				"   .";
		LookUnder:
			if (noun ~= self)
				"   .";
	],
	before [;
		Attack:
			"   .";
		LookUnder:
			"    ,    .";
		Open:
			"  , .";
		Touch, Rub:
			"       .";
	],
  has static container open neuter;

Object -> interrogleads "/"
  with
	name '' '' '' '' '' '' '' '' '',
	description "           ,       ,    .   ,  .       .",
	before [;
		Touch:
			<<Examine self>>;
		Disrobe, Pull:
			"      . ,     ,   .";
		Wear:
			"  .";
		Rub:
			"     ,  -  .";
		Attack, Cut, Taste, Take:
			"   .";
	],
  has scenery pluralname;

Object -> interrogbands "/ /"
  with
	name '' '' '' '' '' '' '' '' '' '' '',
	description "      ,    .        .",
	before [;
		Touch, Rub:
			",       .";
		Disrobe, Pull, Push, Attack:
			print "      .";
			if (self.number < 7)
				print "    ,       .^";
			else
				print "         .^";
			self.number++;
			switch (self.number) {
				2: print "^    .^";
				4: print "^  ,   .      .^";
				6: print "^  .^";
				9: print "^ .^";
				11: self.number = 8;
			}
			rtrue;
		Wear:
			"  .";
		Take:
			"  .";
	],
	number 0,	! counter for the man noticing you.
  has scenery pluralname;

Object -> Himself "/  "
  with
	name '' '' '' '' '' '' '',
	description [;
		print "    .     ,  .   ,       ,     .";
		if (child(self)) {
			print "^^    ";
			WriteListFrom(child(self), ENGLISH_BIT);
			print ".";
		}
		if (child(interrogdesk)) {
			if (child(self)) 
				print " ";
			else
				print "^^";
			print "    ";
            if (children(interrogdesk) > 1) 
                print "";
            else
                print "";
            print " ";
			WriteListFrom(child(interrogdesk), ENGLISH_BIT);
			print ".";
		}
		new_line;
		rtrue;
	],
	react_before [ ix;
		Yes:
			QuestionAnswerYes();
			rtrue;
		No:
			QuestionAnswerNo();
			rtrue;
		VagueSay:
			! allow keywords to fall through so that a device can react_before
			if (consult_words >= 1) {
				wn = consult_from;
				ix = NextWord();
				if (ix == '~//' && consult_words >= 2) {
					ix = NextWord();
				}
				if (ix == 'tango') {
					rfalse;
				}
				if (ix == 'waltz') {
					rfalse;
				}
			}
			<<Answer noun self>>;
		Wait:
			print "  .^^";
			QuestionAnswerWait();
			rtrue;
	],
	before [;
		Search:
			print_ret ",   ", (emphstring) "", "    .";
	],
	life [ ix;
		Answer:
			if (consult_words == 1) {
				wn = consult_from;
				ix = NextWord();
				switch (ix) {
					'', '//':
						QuestionAnswerYes();
						rtrue;
					'', '//', '':
						QuestionAnswerNo();
						rtrue;
					'':
						QuestionAnswerWait();
						rtrue;
				}
			}
	],
	orders [;
		Yes:
			QuestionAnswerYes();
			rtrue;
		No:
			QuestionAnswerNo();
			rtrue;
		Tango:
			<<Tango>>;
		Waltz:
			<<Waltz>>;
		default:
			self.orders_counter++;
			switch (self.orders_counter) {
				1: "@<<?@>>";
				2: "@<< ,   ,   @>>.";
				3: "@<< ,   @>>.";
				4: "@<<  @>>.";
				5: 
					self.orders_counter = 3;
					"  .";
			}
	],
	orders_counter 0,
	daemon [ doneflag;
		doneflag = 0;
		
		if (self hasnt general) {
			print "^  -  . []^";
			return;
		}
		
		while (doneflag == 0 && self has general) {
			doneflag = 1;
			
			if (cur_question == nothing) {
				print "^  . []^";
				return;
			}
			
			if (cur_question.number == 0) {
				cur_question.query();
			}
			
			if (cur_question.daemon ~= 0) {
				cur_question.daemon();
			}
			cur_question.number++;

			if (cur_question.time_limit >= 0) {
				if (cur_question.number > cur_question.time_limit) {
					new_line;
					QuestionAnswerWait();
					! repeat the loop, since a wait answer is an action
					doneflag = 0; 
				}
			}
		}
	],
  has scenery animate transparent female; ! general means daemon-active -- female for case purposes [y4n]

Object -> himself_uniform "/"
  with
	name '' '' '' '',
	description "   -   ,     .",
  has scenery female;

